Learn R Programming

LCCkNN (version 0.1.0)

curvature_estimation: Computes the curvatures of all samples in the training set.

Description

Computes the curvatures of all samples in the training set.

Usage

curvature_estimation(data, k)

Value

A numeric vector of curvatures for each sample.

Arguments

data

A numeric matrix or data frame of the training data.

k

The number of neighbors for the initial k-NN graph.