testa_KNN: Standard k-NN classifier.
Description
Standard k-NN classifier.
Usage
testa_KNN(train, test, train_target, nn)
Value
A numeric or factor vector of predicted class labels.
Arguments
- train
A numeric matrix or data frame of the training data.
- test
A numeric matrix or data frame of the test data.
- train_target
A numeric or factor vector of class labels for the training data.
- nn
The number of neighbors.